@@ -1,8 +1,6 @@
-from typing import Tuple
-
-from astropy.table import Table
+import asyncio
+from typing import Tuple, Any
 import logging
-import numpy as np
 
 from .sourcedetection import SourceDetection
 from pyobs.images import Image
@@ -12,11 +10,18 @@ log = logging.getLogger(__name__)
 
 class DaophotSourceDetection(SourceDetection):
     """Detect source using Daophot."""
-    __module__ = 'pyobs.images.processors.detection'
 
-    def __init__(self, fwhm: float = 3., threshold: float = 4., bkg_sigma: float = 3.,
-                 bkg_box_size: Tuple[int, int] = (50, 50), bkg_filter_size: Tuple[int, int] = (3, 3),
-                 *args, **kwargs):
+    __module__ = "pyobs.images.processors.detection"
+
+    def __init__(
+        self,
+        fwhm: float = 3.0,
+        threshold: float = 4.0,
+        bkg_sigma: float = 3.0,
+        bkg_box_size: Tuple[int, int] = (50, 50),
+        bkg_filter_size: Tuple[int, int] = (3, 3),
+        **kwargs: Any,
+    ):
         """Initializes a wrapper for photutils. See its documentation for details.
 
         Args:
@@ -26,6 +31,7 @@ class DaophotSourceDetection(SourceDetection):
             bkg_box_size: Box size for background estimation.
             bkg_filter_size: Filter size for background estimation.
         """
+        SourceDetection.__init__(self, **kwargs)
 
         # store
         self.fwhm = fwhm
@@ -34,29 +40,35 @@ class DaophotSourceDetection(SourceDetection):
         self.bkg_box_size = bkg_box_size
         self.bkg_filter_size = bkg_filter_size
 
-    def __call__(self, image: Image) -> Table:
+    async def __call__(self, image: Image) -> Image:
         """Find stars in given image and append catalog.
 
         Args:
             image: Image to find stars in.
 
         Returns:
-            Full table with results.
+            Image with attached catalog.
         """
         from astropy.stats import SigmaClip, sigma_clipped_stats
         from photutils import Background2D, MedianBackground, DAOStarFinder
 
         # get data
-        data = image.data.astype(np.float).copy()
-
-        # mask?
-        mask = image.mask.data if image.mask is not None else None
+        if image.data is None:
+            log.warning("No data found in image.")
+            return image
+        data = image.data.astype(float).copy()
 
         # estimate background
         sigma_clip = SigmaClip(sigma=self.bkg_sigma)
         bkg_estimator = MedianBackground()
-        bkg = Background2D(data, self.bkg_box_size, filter_size=self.bkg_filter_size,
-                           sigma_clip=sigma_clip, bkg_estimator=bkg_estimator, mask=mask)
+        bkg = Background2D(
+            data,
+            self.bkg_box_size,
+            filter_size=self.bkg_filter_size,
+            sigma_clip=sigma_clip,
+            bkg_estimator=bkg_estimator,
+            mask=image.mask,
+        )
         data -= bkg.background
 
         # do statistics
@@ -64,24 +76,24 @@ class DaophotSourceDetection(SourceDetection):
 
         # find stars
         daofind = DAOStarFinder(fwhm=self.fwhm, threshold=self.threshold * std)
-        sources = daofind(data - median)
+        loop = asyncio.get_running_loop()
+        sources = await loop.run_in_executor(None, daofind, data - median)
 
         # rename columns
-        sources.rename_column('xcentroid', 'x')
-        sources.rename_column('ycentroid', 'y')
+        sources.rename_column("xcentroid", "x")
+        sources.rename_column("ycentroid", "y")
 
         # match fits conventions
-        sources['x'] += 1
-        sources['y'] += 1
+        sources["x"] += 1
+        sources["y"] += 1
 
         # pick columns for catalog
-        cat = sources['x', 'y', 'flux', 'peak']
+        cat = sources["x", "y", "flux", "peak"]
 
-        # set it
-        image.catalog = cat
-
-        # return full catalog
-        return sources
+        # copy image, set catalog and return it
+        img = image.copy()
+        img.catalog = cat
+        return img
 
 
-__all__ = ['DaophotSourceDetection']
+__all__ = ["DaophotSourceDetection"]
