@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, List, Any
 
 from .interface import Interface
 
 
-class IBinning(Interface):
+class IBinning(Interface, metaclass=ABCMeta):
     """The camera supports binning, to be used together with :class:`~pyobs.interfaces.ICamera`."""
-    __module__ = 'pyobs.interfaces'
 
-    def set_binning(self, x: int, y: int, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def set_binning(self, x: int, y: int, **kwargs: Any) -> None:
         """Set the camera binning.
 
         Args:
@@ -17,23 +20,25 @@ class IBinning(Interface):
         Raises:
             ValueError: If binning could not be set.
         """
-        raise NotImplementedError
+        ...
 
-    def get_binning(self, **kwargs: Any) -> Tuple[int, int]:
+    @abstractmethod
+    async def get_binning(self, **kwargs: Any) -> Tuple[int, int]:
         """Returns the camera binning.
 
         Returns:
             Tuple with x and y.
         """
-        raise NotImplementedError
+        ...
 
-    def list_binnings(self, **kwargs: Any) -> List[Tuple[int, int]]:
+    @abstractmethod
+    async def list_binnings(self, **kwargs: Any) -> List[Tuple[int, int]]:
         """List available binnings.
 
         Returns:
             List of available binnings as (x, y) tuples.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IBinning']
+__all__ = ["IBinning"]
