@@ -2,7 +2,7 @@
 Modules for performing auto-guiding.
 TODO: write doc
 """
-__title__ = 'Auto-guiding'
+__title__ = "Auto-guiding"
 
 from ._baseguiding import BaseGuiding
 from .autoguiding import AutoGuiding
