@@ -2,6 +2,6 @@
 Test modules.
 TODO: write doc
 """
-__title__ = 'Test modules'
+__title__ = "Test modules"
 
 from .standalone import StandAlone
