@@ -1,9 +1,8 @@
+import asyncio
 import logging
 from typing import Tuple, Any, Dict, List, Optional
-
-import requests
+import aiohttp
 import urllib.parse
-import threading
 import astropy.units as u
 
 from pyobs.utils.enums import WeatherSensors
@@ -17,21 +16,22 @@ log = logging.getLogger(__name__)
 
 
 FITS_HEADERS = {
-    WeatherSensors.TEMPERATURE: ('WS-TEMP', 'Ambient temperature average during exposure, C', float),
-    WeatherSensors.HUMIDITY: ('WS-HUMID', 'Ambient rel. humidity average, %', float),
-    WeatherSensors.PRESSURE: ('WS-PRESS', 'Average atmospheric pressure, hPa', float),
-    WeatherSensors.WINDDIR: ('WS-AZ', 'Average wind direction, not corrected for overlap, deg', float),
-    WeatherSensors.WINDSPEED: ('WS-WIND', 'Ambient average wind speed, km/h', float),
-    WeatherSensors.RAIN: ('WS-PREC', 'Ambient precipitation [0/1]', bool),
-    WeatherSensors.SKYTEMP: ('WS-SKY', 'Average sky temperature, C', float),
-    WeatherSensors.DEWPOINT: ('WS-TDEW', 'Ambient dewpoint average during expsoure, C', float),
-    WeatherSensors.PARTICLES: ('WS-DUST', 'Average particle count during exposure, ppcm', float)
+    WeatherSensors.TEMPERATURE: ("WS-TEMP", "Ambient temperature average during exposure, C", float),
+    WeatherSensors.HUMIDITY: ("WS-HUMID", "Ambient rel. humidity average, %", float),
+    WeatherSensors.PRESSURE: ("WS-PRESS", "Average atmospheric pressure, hPa", float),
+    WeatherSensors.WINDDIR: ("WS-AZ", "Average wind direction, not corrected for overlap, deg", float),
+    WeatherSensors.WINDSPEED: ("WS-WIND", "Ambient average wind speed, km/h", float),
+    WeatherSensors.RAIN: ("WS-PREC", "Ambient precipitation [0/1]", bool),
+    WeatherSensors.SKYTEMP: ("WS-SKY", "Average sky temperature, C", float),
+    WeatherSensors.DEWPOINT: ("WS-TDEW", "Ambient dewpoint average during expsoure, C", float),
+    WeatherSensors.PARTICLES: ("WS-DUST", "Average particle count during exposure, ppcm", float),
 }
 
 
 class Weather(Module, IWeather, IFitsHeaderBefore):
     """Connection to pyobs-weather."""
-    __module__ = 'pyobs.modules.weather'
+
+    __module__ = "pyobs.modules.weather"
 
     def __init__(self, url: str, system_init_time: int = 300, **kwargs: Any):
         """Initialize a new pyobs-weather connector.
@@ -45,7 +45,6 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
         # store and create session
         self._system_init_time = system_init_time
         self._url = url
-        self._session = requests.session()
 
         # whether module is active, i.e. if None, weather is always good
         self._active = True
@@ -55,67 +54,67 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
 
         # whole status
         self._status: Dict[str, Any] = {}
-        self._status_lock = threading.RLock()
 
         # add thread func
-        self.add_thread_func(self._update, True)
+        self.add_background_task(self._update, True)
 
-    def open(self) -> None:
+    async def open(self) -> None:
         """Open module."""
-        Module.open(self)
+        await Module.open(self)
 
         # subscribe to events
         if self.comm:
-            self.comm.register_event(BadWeatherEvent)
-            self.comm.register_event(GoodWeatherEvent)
+            await self.comm.register_event(BadWeatherEvent)
+            await self.comm.register_event(GoodWeatherEvent)
 
-    def start(self, **kwargs: Any) -> None:
+    async def start(self, **kwargs: Any) -> None:
         """Starts a service."""
 
         # did status change and weather is now bad?
         if not self._active and not self._is_good:
             # send event!
-            self.comm.send_event(BadWeatherEvent())
+            await self.comm.send_event(BadWeatherEvent())
 
         # activate
         self._active = True
 
-    def stop(self, **kwargs: Any) -> None:
+    async def stop(self, **kwargs: Any) -> None:
         """Stops a service."""
         self._active = False
 
-    def is_running(self, **kwargs: Any) -> bool:
+    async def is_running(self, **kwargs: Any) -> bool:
         """Whether a service is running."""
         return self._active
 
-    def _update(self) -> None:
+    async def _update(self) -> None:
         """Update weather info."""
 
         # loop forever
-        while not self.closing.is_set():
+        while True:
             # new is_good status
             is_good: Optional[bool] = None
             error = False
 
             try:
                 # fetch status
-                res = self._session.get(urllib.parse.urljoin(self._url, 'api/current/'), timeout=5)
-                if res.status_code != 200:
-                    raise ValueError('Could not connect to weather station.')
+                url = urllib.parse.urljoin(self._url, "api/current/")
+                async with aiohttp.ClientSession() as session:
+                    async with session.get(url, timeout=5) as response:
+                        if response.status != 200:
+                            raise ValueError("Could not connect to weather station.")
+                        status = await response.json()
 
                 # to json
-                status = res.json()
-                if 'good' not in status:
-                    raise ValueError('Good parameter not found in response from weather station.')
+                if "good" not in status:
+                    raise ValueError("Good parameter not found in response from weather station.")
 
                 # store it
-                is_good = status['good']
-                with self._status_lock:
-                    self._status = status
+                is_good = status["good"]
+                self._status = status
 
-            except (requests.exceptions.Timeout, requests.exceptions.ConnectionError, ValueError) as e:
+            except Exception as e:
                 # on error, we're always bad
-                log.error('Request failed: %s', e)
+                log.error("Request failed: %s", e)
                 is_good = False
                 error = True
 
@@ -125,24 +124,24 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
                 if self._active:
                     # did it change to good or bad?
                     if is_good:
-                        log.info(('Weather is now good.'))
+                        log.info("Weather is now good.")
                         eta = Time.now() + self._system_init_time * u.second
-                        self.comm.send_event(GoodWeatherEvent(eta=eta))
+                        await self.comm.send_event(GoodWeatherEvent(eta=eta))
                     else:
-                        log.info('Weather is now bad.')
-                        self.comm.send_event(BadWeatherEvent())
+                        log.info("Weather is now bad.")
+                        await self.comm.send_event(BadWeatherEvent())
 
                 # store new state
                 self._is_good = is_good
 
             # sleep a little
-            self.closing.wait(60 if error else 5)
+            await asyncio.sleep(60 if error else 5)
 
-    def get_weather_status(self, **kwargs: Any) -> Dict[str, Any]:
+    async def get_weather_status(self, **kwargs: Any) -> Dict[str, Any]:
         """Returns status of object in form of a dictionary. See other interfaces for details."""
         raise NotImplementedError
 
-    def is_weather_good(self, **kwargs: Any) -> bool:
+    async def is_weather_good(self, **kwargs: Any) -> bool:
         """Whether the weather is good to observe."""
 
         # if not active, weather is always good
@@ -152,17 +151,16 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
         # otherwise it depends on the is_good flag
         return False if self._is_good is None else self._is_good
 
-    def get_current_weather(self, **kwargs: Any) -> Dict[str, Any]:
+    async def get_current_weather(self, **kwargs: Any) -> Dict[str, Any]:
         """Returns current weather.
 
         Returns:
             Dictionary containing entries for time, good, and sensor, with the latter being another dictionary
             with sensor information, which contain a value and a good flag.
         """
-        with self._status_lock:
-            return self._status
+        return self._status
 
-    def get_sensor_value(self, station: str, sensor: WeatherSensors, **kwargs: Any) -> Tuple[str, float]:
+    async def get_sensor_value(self, station: str, sensor: WeatherSensors, **kwargs: Any) -> Tuple[str, float]:
         """Return value for given sensor.
 
         Args:
@@ -174,21 +172,23 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
         """
 
         # do request
-        url = urllib.parse.urljoin(self._url, 'api/stations/%s/%s/' % (station, sensor.value))
-        res = self._session.get(url)
-        if res.status_code != 200:
-            raise ValueError('Could not connect to weather station.')
+        url = urllib.parse.urljoin(self._url, "api/stations/%s/%s/" % (station, sensor.value))
+        async with aiohttp.ClientSession() as session:
+            async with session.get(url, timeout=5) as response:
+                if response.status != 200:
+                    raise ValueError("Could not connect to weather station.")
+                status = await response.json()
 
         # to json
-        status = res.json()
-        if 'time' not in status or 'value' not in status:
-            raise ValueError('Time and/or value parameters not found in response from weather station.')
+        if "time" not in status or "value" not in status:
+            raise ValueError("Time and/or value parameters not found in response from weather station.")
 
         # return time and value
-        return status['time'], status['value']
+        return status["time"], status["value"]
 
-    def get_fits_header_before(self, namespaces: Optional[List[str]] = None, **kwargs: Any) \
-            -> Dict[str, Tuple[Any, str]]:
+    async def get_fits_header_before(
+        self, namespaces: Optional[List[str]] = None, **kwargs: Any
+    ) -> Dict[str, Tuple[Any, str]]:
         """Returns FITS header for the current status of this module.
 
         Args:
@@ -199,14 +199,13 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
         """
 
         # copy status
-        with self._status_lock:
-            status = dict(self._status)
+        status = dict(self._status)
 
         # got sensors?
-        if 'sensors' not in status:
-            log.error('No sensor data found in status.')
+        if "sensors" not in status:
+            log.error("No sensor data found in status.")
             return {}
-        sensors = status['sensors']
+        sensors = status["sensors"]
 
         # loop sensor types
         header = {}
@@ -214,9 +213,9 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
             # got a value for this type?
             if sensor_type.value in sensors:
                 # get value
-                if 'value' not in sensors[sensor_type.value]:
+                if "value" not in sensors[sensor_type.value]:
                     continue
-                value = sensors[sensor_type.value]['value']
+                value = sensors[sensor_type.value]["value"]
 
                 # get header keyword, comment and data type
                 key, comment, dtype = FITS_HEADERS[sensor_type]
@@ -228,4 +227,4 @@ class Weather(Module, IWeather, IFitsHeaderBefore):
         return header
 
 
-__all__ = ['Weather']
+__all__ = ["Weather"]
