@@ -1,7 +1,7 @@
 import time
 from collections import namedtuple
 from threading import Lock
-from typing import Any, List, Dict
+from typing import Any, Dict
 
 
 class DataCacheEntry:
@@ -37,7 +37,7 @@ class DataCache(object):
     """Data cache for proxy server."""
 
     """Type for cache entries."""
-    Entry = namedtuple('Entry', 'time name data')
+    Entry = namedtuple("Entry", "time name data")
 
     def __init__(self, size: int = 20):
         """Init cache.
@@ -99,10 +99,10 @@ class DataCache(object):
             # check size
             if len(self._cache) > self._size:
                 # sort cache values by update time
-                cache = sorted(self._cache.values(), key=lambda c: c.time, reverse=True)
+                cache = sorted(self._cache.values(), key=lambda x: x.time, reverse=True)
 
                 # delete all elements except for the latest N
-                for c in cache[self._size:]:
+                for c in cache[self._size :]:
                     del self._cache[c.name]
 
     def __delitem__(self, name: str) -> None:
@@ -114,4 +114,4 @@ class DataCache(object):
         del self._cache[name]
 
 
-__all__ = ['DataCache']
+__all__ = ["DataCache"]
